-- buildsys macros routines, safe to use at RPM build stage

local   fedora = require "fedora.common"
local buildsys = require "fedora.srpm.buildsys"

local namespace = buildsys.namespace
local radicals  = buildsys.radicals

local function build(verbose)
  fedora.set_verbose(verbose)
  local vars = fedora.qualify(radicals, namespace)
  local lines = {}
  for _, var in ipairs(vars) do
    local line = "%{?" .. var .. ":last_" .. var .. " = %{" .. var .. "}}"
    if fedora.expand(line) ~= "" then
      table.insert(lines, line)
    end
  end
  print(rpm.expand([[
%{?__current_shell_quiet}
cat > '%{_sourcedir}/%{]] .. namespace .. [[_conf}' << EOF
]] .. table.concat(lines, "\n") .. [[

EOF

cat > '%{_sourcedir}/%{]] .. namespace .. [[_changelog_file}' << EOF
%{buildsys_changelog_content}EOF

rpm -qa --qf '%%{name}\t%%{evr}\t"%%{epoch}"\t"%%{version}"\t"%%{release}"\n' | sort > '%{_sourcedir}/%{]] .. namespace .. [[_state}'
%{?__current_shell_verbose}
]]))
end

return {
  build     = build,
}
